@@ -9,6 +9,7 @@ import json
 import os
 import dateutil
 from datetime import datetime
+import re
 
 class bcolors:
     HEADER = '\033[95m'
@@ -55,11 +56,38 @@ class AgentLifeCycle:
                 else:
                     if(container_name == "cgs_agent"):
                         print(cgs_agent_status)
+                    elif(container_name == "remote_intervention_agent"):
+                        object.parseRemoteInterventionAgentLogs(container.logs(tail=50))                        
                     else:
                         print(f"{bcolors.OKBLUE}ONLINE{bcolors.ENDC}")
             except docker.errors.NotFound:
                 print(f"{bcolors.FAIL}CONTAINER NOT FOUND{bcolors.ENDC}")
     
+    def parseRemoteInterventionAgentLogs(object, logs):
+        logs_lines = logs.splitlines()
+        # parse logs to get current status
+        ri_agent_status = {}
+        ri_agent_status["AGENT"] = ""
+        ri_agent_status["WEBRTC"] = ""
+        ri_agent_status["WEBSOCKET"] = ""
+        for line in reversed(logs_lines):
+            for key,value in ri_agent_status.items():
+                if(value != ""):
+                    continue
+                matches = re.search(rf'^.*{key}:: STATUS:: (?P<status>.*)\\.*$', str(line))
+                if(matches is not None):
+                    ri_agent_status[key] = matches.groups(0)[0]
+            if(ri_agent_status["AGENT"] != "" and ri_agent_status["WEBRTC"] != "" and ri_agent_status["WEBSOCKET"] != ""):
+                continue
+        if(ri_agent_status["AGENT"] == "OK" and ri_agent_status["WEBRTC"] == "OK" and ri_agent_status["WEBSOCKET"] == "OK"):
+            print(f"{bcolors.OKBLUE}ONLINE{bcolors.ENDC}")
+        else:
+            for key,value in ri_agent_status.items():
+                if(value == ""):
+                    print(f"{bcolors.WARNING} NOT INITIALIZED {bcolors.ENDC}")
+                if(value != "OK"):
+                    print(f"{bcolors.WARNING} {key} {value} {bcolors.ENDC}")
+
     def restart(object, args):
         print("Restarting agents")
         object.remove_agents(args)
@@ -98,6 +126,7 @@ class AgentLifeCycle:
                 options["detach"] = True
                 options["environment"] = args.config.config
                 options["restart_policy"] = {"Name":"unless-stopped"}
+                options["tty"] = True
                 command = options.pop("command")
                 container = client.containers.run(object._docker_images[container_name], command, **options)
                 print(f"{bcolors.OKBLUE}DONE{bcolors.ENDC}")
